polar2grid.readers package
==========================

Submodules
----------

.. toctree::
   :maxdepth: 4

   polar2grid.readers._base
   polar2grid.readers.abi_l1b
   polar2grid.readers.abi_l2_nc
   polar2grid.readers.acspo
   polar2grid.readers.agri_fy4a_l1
   polar2grid.readers.agri_fy4b_l1
   polar2grid.readers.ahi_hrit
   polar2grid.readers.ahi_hsd
   polar2grid.readers.ami_l1b
   polar2grid.readers.amsr2_l1b
   polar2grid.readers.amsr2_l2_gaasp
   polar2grid.readers.avhrr_l1b_aapp
   polar2grid.readers.clavrx
   polar2grid.readers.glm_l2
   polar2grid.readers.mersi2_l1b
   polar2grid.readers.mirs
   polar2grid.readers.modis_l1b
   polar2grid.readers.modis_l2
   polar2grid.readers.nucaps
   polar2grid.readers.viirs_edr_active_fires
   polar2grid.readers.viirs_edr_flood
   polar2grid.readers.viirs_l1b
   polar2grid.readers.viirs_sdr
   polar2grid.readers.virr_l1b

Module contents
---------------

.. automodule:: polar2grid.readers
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
